[Author Prev][Author Next][Thread Prev][Thread Next][Author Index][Thread Index]
[tor-commits] [torbutton/master] Bug 33890: Rename xul files to xhtml
commit 6c3d159ae4fbf133cbbbad242b482d139a68a2e4
Author: Alex Catarineu <acat@xxxxxxxxxxxxxx>
Date: Thu Apr 9 20:48:45 2020 +0200
Bug 33890: Rename xul files to xhtml
Also remove a customizeToolbar.xul line from chrome.manifest,
since it's not needed.
---
chrome.manifest | 1 -
chrome/content/tor-circuit-display.js | 2 +-
components/external-app-blocker.js | 4 ++--
3 files changed, 3 insertions(+), 4 deletions(-)
diff --git a/chrome.manifest b/chrome.manifest
index 6d9d12d4..ab1c1420 100644
--- a/chrome.manifest
+++ b/chrome.manifest
@@ -132,7 +132,6 @@ locale torbutton zh-TW chrome/locale/zh-TW/
locale torbutton zu chrome/locale/zu/
skin torbutton classic/1.0 chrome/skin/
-style chrome://global/content/customizeToolbar.xul chrome://torbutton/skin/torbutton.css
# Firefox 4-style component registration
component {f605ec27-d867-44b5-ad97-2a29276642c3} components/dragDropFilter.js
diff --git a/chrome/content/tor-circuit-display.js b/chrome/content/tor-circuit-display.js
index 119f6fca..8a51bbfd 100644
--- a/chrome/content/tor-circuit-display.js
+++ b/chrome/content/tor-circuit-display.js
@@ -5,7 +5,7 @@
// call earlier functions). The file can be processed
// with docco.js to produce pretty documentation.
//
-// This script is to be embedded in torbutton.xul. It defines a single global
+// This script is to be embedded in torbutton.xhtml. It defines a single global
// function, createTorCircuitDisplay(), which activates the automatic Tor
// circuit display for the current tab and any future tabs.
//
diff --git a/components/external-app-blocker.js b/components/external-app-blocker.js
index 9d5cbd79..89d6d252 100644
--- a/components/external-app-blocker.js
+++ b/components/external-app-blocker.js
@@ -73,7 +73,7 @@ ExternalAppBlocker.prototype =
/*
* The _showPrompt() implementation uses some XUL and JS that is part of the
* browser's confirmEx() implementation. Specifically, _showPrompt() depends
* on chrome://global/content/commonDialog.xul as well as some of the code
* in resource://gre/modules/SharedPromptUtils.jsm.
*/
_showPrompt: function(aWindowContext) {
@@ -107,7 +107,7 @@ ExternalAppBlocker.prototype =
};
let propBag = PromptUtils.objectToPropBag(args);
- let uri = "chrome://global/content/commonDialog.xul";
+ let uri = "chrome://global/content/commonDialog.xhtml";
let promptWin = Services.ww.openWindow(parentWin, uri, "_blank",
"centerscreen,chrome,titlebar", propBag);
promptWin.addEventListener("load", aEvent => {
@@ -73,7 +73,7 @@ ExternalAppBlocker.prototype =
* The _showPrompt() implementation uses some XUL and JS that is part of the
* browser's confirmEx() implementation. Specifically, _showPrompt() depends
- * on chrome://global/content/commonDialog.xul as well as some of the code
+ * on chrome://global/content/commonDialog.xhtml as well as some of the code
* in resource://gre/modules/SharedPromptUtils.jsm.
*/
_______________________________________________
tor-commits mailing list
tor-commits@xxxxxxxxxxxxxxxxxxxx
https://lists.torproject.org/cgi-bin/mailman/listinfo/tor-commits